@@ -1,5 +1,5 @@
-import mid_pt
-import cube_face_COM_coord
+from .mid_pt import mid_pt
+from .cube_face_COM_coord import cube_face_COM_coord
 
 
 def cube_face_COM_leg_coord(a: float, b: float, c: float, d: float):
