@@ -1,4 +1,4 @@
-import cube_vert_write
+from .cube_vert_write import cube_vert_write
 
 
 def cube_vert(radius: float, sigma: float):
