@@ -1,4 +1,4 @@
-import octa_vert_write
+from .octa_vert_write import octa_vert_write
 
 
 def octa_vert(radius: float, sigma: float):
